
# $rcs = ' $Id: Ebay.pm,v 1.25 2008/10/22 02:58:25 Martin Exp $ ' ;

=head1 NAME

WWW::Ebay - Search and manage eBay auctions

=head1 DESCRIPTION

This is an empty module.  It only exists so that CPAN users can say
"install WWW::Ebay" (and CPANPLUS users can say "i WWW::Ebay") and
they'll get what they expect.  Well, actually I'm not sure what they
expect, but they'll get something reasonable.

It is also used to control the version number of the distribution.

=head1 SEE ALSO

L<WWW::Ebay::Customer|WWW::Ebay::Customer>,
L<WWW::Ebay::Listing|WWW::Ebay::Listing>,
L<WWW::Ebay::Search|WWW::Ebay::Search>,
L<WWW::Ebay::Session|WWW::Ebay::Session>,
L<WWW::Ebay::Status|WWW::Ebay::Status>,
L<WWW::Search::Ebay|WWW::Search::Ebay>,
L<WWW::Search::Ebay::Completed|WWW::Search::Ebay::Completed>

=head1 AUTHOR

Martin Thurn, C<mthurn@cpan.org>, L<http://www.sandcrawler.com/SWB/cpan-modules.html>.

=head1 LICENSE

This software is released under the same license as Perl itself.

=cut

package WWW::Ebay;

use strict;
use warnings;

our
$VERSION = '0.086';

1;

__END__

